flash_range_program

Function flash_range_program 

pub fn flash_range_program(addr: u32, data: *const u8, count: usize)
Program data to a range of flash addresses starting at addr (offset from the start of flash) and count bytesin size. addr must be aligned to a 256-byte boundary, and count must be a multiple of 256.