float_to_uint

Function float_to_uint 

pub fn float_to_uint() -> extern "C" fn(v: f32) -> u32
Convert a float to an unsigned integer, rounding towards -INFINITY, and clamping the result to lie within the range 0x00000000 to 0xFFFFFFFF